summaryrefslogtreecommitdiffstats
path: root/bin/d-i_manual.sh
diff options
context:
space:
mode:
authorHolger Levsen <holger@layer-acht.org>2014-11-01 12:31:18 +0100
committerHolger Levsen <holger@layer-acht.org>2014-11-01 12:31:18 +0100
commitf21fdd09b6a6ef7b14f0eb9da8b5f7c7ac10673f (patch)
tree7c69076910f33dabc8e6b939d161b6d2611357a8 /bin/d-i_manual.sh
parent674fc600746ea5c4fb60576d59240c3a42719fbb (diff)
downloadjenkins.debian.net-f21fdd09b6a6ef7b14f0eb9da8b5f7c7ac10673f.tar.xz
d-i builds: cleanup before+after builds
Diffstat (limited to 'bin/d-i_manual.sh')
-rwxr-xr-xbin/d-i_manual.sh22
1 files changed, 16 insertions, 6 deletions
diff --git a/bin/d-i_manual.sh b/bin/d-i_manual.sh
index df1b847f..1a4d18a3 100755
--- a/bin/d-i_manual.sh
+++ b/bin/d-i_manual.sh
@@ -7,16 +7,25 @@ DEBUG=false
. /srv/jenkins/bin/common-functions.sh
common_init "$@"
-init_workspace() {
+clean_workspace() {
#
# clean
#
- rm -fv *.deb *.dsc *_*.build *_*.changes *_*.tar.gz
-
+ cd $WORKSPACE
+ cd ..
+ rm -fv *.deb *.udeb *.dsc *_*.build *_*.changes *_*.tar.gz *_*.tar.bz2 *_*.tar.xz *_*.buildinfo
+ cd workspace
#
# svn checkout and update is done by jenkins job
#
- svn status
+ if [ -d .git ] ; then
+ echo "git status:"
+ git status
+ elif [ -f .svn ] ; then
+ echo "svn status:"
+ svn status
+ fi
+ echo
}
pdebuild_package() {
@@ -106,7 +115,7 @@ po_cleanup() {
rm -rv manual/$1 manual/integrated
}
-init_workspace
+clean_workspace
#
# if $1 is not given, build the whole manual,
# else just the language $1 in format $2
@@ -129,3 +138,4 @@ else
po_cleanup $1
fi
fi
+clean_workspace
@@ -7,16 +7,25 @@ DEBUG=false
#
- # svn checkout and update is done by jenkins job
+ # git clone and pull is done by jenkins job
#